IV
constant()
    ALIAS:
        MECAB_SYS_DIC = MECAB_SYS_DIC
        MECAB_UNK_NODE = MECAB_UNK_NODE
        MECAB_UNK_DIC = MECAB_UNK_DIC
        MECAB_USR_DIC = MECAB_USR_DIC
        MECAB_EOS_NODE = MECAB_EOS_NODE
        MECAB_NOR_NODE = MECAB_NOR_NODE
        MECAB_EON_NODE = MECAB_EON_NODE
        MECAB_BOS_NODE = MECAB_BOS_NODE
    CODE:
        RETVAL = ix;
    OUTPUT:
        RETVAL